@@ -131,10 +131,12 @@ export async function defaultPackageCreator(
 
   let extensionName: string = manifestData.name;
 
-  if (manifestData.default_locale) {
+  let {default_locale} = manifestData;
+  if (default_locale) {
+    default_locale = default_locale.replace(/-/g, '_');
     const messageFile = path.join(
       sourceDir, '_locales',
-      manifestData.default_locale, 'messages.json'
+      default_locale, 'messages.json'
     );
     log.debug('Manifest declared default_locale, localizing extension name');
     extensionName = await getDefaultLocalizedName({
@@ -146,7 +148,7 @@ export async function defaultPackageCreator(
   const extensionPath = path.join(artifactsDir, packageName);
 
   // Added 'wx' flags to avoid overwriting of existing package.
-  let stream = createWriteStream(extensionPath, {flags: 'wx'});
+  const stream = createWriteStream(extensionPath, {flags: 'wx'});
 
   stream.write(buffer, () => stream.end());
 
@@ -162,9 +164,9 @@ export async function defaultPackageCreator(
         'Use --overwrite-dest to enable overwriting.');
     }
     log.info(`Destination exists, overwriting: ${extensionPath}`);
-    stream = createWriteStream(extensionPath);
-    stream.write(buffer, () => stream.end());
-    await eventToPromise(stream, 'close');
+    const overwriteStream = createWriteStream(extensionPath);
+    overwriteStream.write(buffer, () => overwriteStream.end());
+    await eventToPromise(overwriteStream, 'close');
   }
 
   if (showReadyMessage) {
