@@ -1,5 +1,6 @@
 /* @flow */
+import {promisify} from 'util';
+
 import zipDirModule from 'zip-dir';
-import promisify from 'es6-promisify';
 
 export const zipDir = promisify(zipDirModule);
