@@ -29,9 +29,17 @@ http.createServer(function(req, res) {
   const reply = FAKE_REPLIES[replyIndex++];
 
   if (reply) {
-    res.writeHead(200, {'content-type': 'application/json'});
-    res.write(JSON.stringify(reply));
-    res.end();
+    req.on('data', function() {
+      // Ignore request body.
+    });
+    // Wait for the transfer of the request body to finish before sending a response.
+    // Otherwise the client could experience an EPIPE error:
+    // https://github.com/nodejs/node/issues/12339
+    req.once('end', function() {
+      res.writeHead(200, {'content-type': 'application/json'});
+      res.write(JSON.stringify(reply));
+      res.end();
+    });
   } else {
     process.exit(1);
   }
